summaryrefslogtreecommitdiff
path: root/src/mongo/db/cursor_manager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/cursor_manager.cpp')
-rw-r--r--src/mongo/db/cursor_manager.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/cursor_manager.cpp b/src/mongo/db/cursor_manager.cpp
index ac9c41accfd..34f7d7bdce0 100644
--- a/src/mongo/db/cursor_manager.cpp
+++ b/src/mongo/db/cursor_manager.cpp
@@ -214,10 +214,10 @@ StatusWith<ClientCursorPin> CursorManager::pinCursor(
CurOp::get(opCtx)->debug().queryHash = cursor->_queryHash;
CurOp::get(opCtx)->debug().planCacheKey = cursor->_planCacheKey;
- // Pass along telemetry context so it is retrievable after query execution for storing metrics.
- CurOp::get(opCtx)->debug().telemetryStoreKeyHash = cursor->_telemetryStoreKeyHash;
- // TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
- CurOp::get(opCtx)->debug().telemetryStoreKey = cursor->_telemetryStoreKey;
+ // Pass along queryStats context so it is retrievable after query execution for storing metrics.
+ CurOp::get(opCtx)->debug().queryStatsStoreKeyHash = cursor->_queryStatsStoreKeyHash;
+ // TODO: SERVER-73152 remove queryStatsStoreKey when RequestShapifier is used for agg.
+ CurOp::get(opCtx)->debug().queryStatsStoreKey = cursor->_queryStatsStoreKey;
cursor->_operationUsingCursor = opCtx;